Pharmacology - Wikipedia

Jump to content

# Pharmacology

91 languages

- العربية
- Asturianu
- Azərbaycanca
- تۆرکجه
- বাংলা
- 閩南語 / Bân-lâm-gí
- Башҡортса
- Беларуская
- Беларуская (тарашкевіца)
- Български
- Bosanski
- Català
- Čeština
- Cymraeg
- Dansk
- Deutsch
- Eesti
- Ελληνικά
- Español
- Esperanto
- Euskara
- فارسی
- Français
- Gaeilge
- Galego
- 한국어
- Hausa
- Հայերեն
- हिन्दी
- Hrvatski
- Ido
- Bahasa Indonesia
- Interlingua
- Íslenska
- Italiano
- עברית
- Jawa
- ಕನ್ನಡ
- ქართული
- Қазақша
- Kurdî
- Кыргызча
- ລາວ
- Latina
- Latviešu
- Lietuvių
- Lombard
- Magyar
- Македонски
- മലയാളം
- მარგალური
- مصرى
- Bahasa Melayu
- Minangkabau
- မြန်မာဘာသာ
- Nederlands
- 日本語
- Norsk bokmål
- Norsk nynorsk
- Occitan
- Oʻzbekcha / ўзбекча
- پښتو
- Polski
- Português
- Română
- Русский
- Scots
- Shqip
- සිංහල
- Simple English
- Slovenčina
- Slovenščina
- کوردی
- Српски / srpski
- Srpskohrvatski / српскохрватски
- Sunda
- Suomi
- Svenska
- Tagalog
- தமிழ்
- Татарча / tatarça
- ไทย
- Тоҷикӣ
- Türkçe
- Українська
- اردو
- Tiếng Việt
- Winaray
- 吴语
- 粵語
- 中文

Edit links
From Wikipedia, the free encyclopedia
Science of drugs and medications and their effects

| This article may require cleanup to meet Wikipedia's quality standards. The specific problem is: 1) Order of sections needs to be addressed (e.g., there are 2 sections each for pharmacodynamics and for pharmacokinetics), 2) Several sections are incomplete, 3) Several sections are missing citations. Please help improve this article if you can. (October 2025) (Learn how and when to remove this message)

Pharmacology
Diagrammatic representation of organ bath used for studying the effect of isolated tissues
MeSH Unique ID | D010600

Pharmacology is the science of drugs and medications,[1] including a substance's origin, composition, pharmacokinetics, pharmacodynamics, therapeutic use, and toxicology. More specifically, it is the study of the interactions that occur between a living organism and chemicals that affect normal or abnormal biochemical function.[2] If substances have medicinal properties, they are considered pharmaceuticals.

The field encompasses drug composition and properties, functions, sources, synthesis and drug design, molecular and cellular mechanisms, organ/systems mechanisms, signal transduction/cellular communication, molecular diagnostics, interactions, chemical biology, therapy, and medical applications, and antipathogenic capabilities. The two main areas of pharmacology are pharmacodynamics and pharmacokinetics. Pharmacodynamics studies the effects of a drug on biological systems, and pharmacokinetics studies the effects of biological systems on a drug. In broad terms, pharmacodynamics discusses the chemicals with biological receptors, and pharmacokinetics discusses the absorption, distribution, metabolism, and excretion (ADME) of chemicals from the biological systems.

Pharmacology is not synonymous with pharmacy and the two terms are frequently confused. Pharmacology, one of the branches of pharmacy(or medical sciences) with the research, discovery, and characterization of chemicals which show biological effects and the elucidation of cellular and organismal function in relation to these chemicals. In contrast, pharmacy, a health services profession, is concerned with the application of the principles learned from pharmacology, pharmaceutics, medicinal chemistry, pharmacognosy, clinical pharmacy and others in its clinical settings; whether it be in a dispensing or clinical care role. In either field, the primary contrast between the two is their distinctions between direct-patient care, pharmacy practice, and the science-oriented research field, driven by pharmacology.

## Etymology

[edit]

The word pharmacology is derived from Greek word φάρμακον, pharmakon, meaning "drug" or "poison", together with another Greek word -λογία, logia with the meaning of "study of" or "knowledge of"[3][4] (cf. the etymology of pharmacy). Pharmakon is related to pharmakos, the ritualistic sacrifice or exile of a human scapegoat or victim in Ancient Greek religion.

The modern term pharmacon is used more broadly than the term drug because it includes endogenous substances, and biologically active substances which are not used as drugs. Typically it includes pharmacological agonists and antagonists, but also enzyme inhibitors (such as monoamine oxidase inhibitors).[5]

## History

[edit]
Naturally derived opium from opium poppies has been used as a drug since before 1100 BCE.[6]
Opium's major active constituent, morphine, was first isolated in 1804 and is now known to act as an opioid agonist.[7][8]

The origins of clinical pharmacology date back to the Middle Ages, with pharmacognosy and Avicenna's The Canon of Medicine, Peter of Spain's Commentary on Isaac, and John of St Amand's Commentary on the Antedotary of Nicholas.[9] Early pharmacology focused on herbalism and natural substances, mainly plant extracts. Medicines were compiled in books called pharmacopoeias. Crude drugs have been used since prehistory as a preparation of substances from natural sources. However, the active ingredient of crude drugs are not purified and the substance is adulterated with other substances.

Traditional medicine varies between cultures and may be specific to a particular culture, such as in traditional Chinese, Mongolian, Tibetan, and Korean medicine. However much of this has since been regarded as pseudoscience. Pharmacological substances known as entheogens may have spiritual and religious use and historical context.

In the 17th century, the English physician Nicholas Culpeper translated and used pharmacological texts. Culpeper detailed plants and the conditions they could treat. In the 18th century, much of clinical pharmacology was established by the work of William Withering.[10] Pharmacology as a scientific discipline did not further advance until the mid-19th century amid the great biomedical resurgence of that period.[11] Before the second half of the nineteenth century, the remarkable potency and specificity of the actions of drugs such as morphine, quinine, and digitalis were explained vaguely and with reference to extraordinary chemical powers and affinities to certain organs or tissues.[12] The first pharmacology department was set up by Rudolf Buchheim in 1847, at University of Tartu, in recognition of the need to understand how therapeutic drugs and poisons produced their effects.[11] Subsequently, the first pharmacology department in England was set up in 1905 at University College London.

Pharmacology developed in the 19th century as a biomedical science that applied the principles of scientific experimentation to therapeutic contexts.[13] The advancement of research techniques propelled pharmacological research and understanding. The development of the organ bath preparation, where tissue samples are connected to recording devices, such as a myograph, and physiological responses are recorded after drug application, allowed analysis of drugs' effects on tissues. The development of the ligand binding assay in 1945 allowed quantification of the binding affinity of drugs at chemical targets.[14] Modern pharmacologists use techniques from genetics, molecular biology, biochemistry, and other advanced tools to transform information about molecular mechanisms and targets into therapies directed against disease, defects or pathogens, and create methods for preventive care, diagnostics, and ultimately personalized medicine.

## Divisions

[edit]

The discipline of pharmacology can be divided into many sub disciplines each with a specific focus.

Areas within Pharmacology

### Systems of the body

[edit]
A variety of topics involved with pharmacology, including neuropharmacology, renal pharmacology, human metabolism, intracellular metabolism, and intracellular regulation

Pharmacology can also focus on specific systems comprising the body. Divisions related to bodily systems study the effects of drugs in different systems of the body. These include neuropharmacology, in the central and peripheral nervous systems; immunopharmacology in the immune system. Other divisions include cardiovascular, renal, and endocrine pharmacology. Psychopharmacology is the study of the use of drugs that affect the psyche, mind, and behaviour (e.g. antidepressants) in treating mental disorders (e.g. depression).[15][16] It incorporates approaches and techniques from neuropharmacology, animal behaviour and behavioural neuroscience, and is interested in the behavioural and neurobiological mechanisms of action of psychoactive drugs.[citation needed] The related field of neuropsychopharmacology focuses on the effects of drugs at the overlap between the nervous system and the psyche.

Pharmacometabolomics, also known as pharmacometabonomics, is a field which stems from metabolomics, the quantification and analysis of metabolites produced by the body.[17][18] It refers to the direct measurement of metabolites in an individual's bodily fluids, in order to predict or evaluate the metabolism of pharmaceutical compounds, and to better understand the pharmacokinetic profile of a drug.[17][18] Pharmacometabolomics can be applied to measure metabolite levels following the administration of a drug, in order to monitor the effects of the drug on metabolic pathways. Pharmacomicrobiomics studies the effect of microbiome variations on drug disposition, action, and toxicity.[19] Pharmacomicrobiomics is concerned with the interaction between drugs and the gut microbiome. Pharmacogenomics is the application of genomic technologies to drug discovery and further characterization of drugs related to an organism's entire genome.[citation needed] For pharmacology regarding individual genes, pharmacogenetics studies how genetic variation gives rise to differing responses to drugs.[citation needed] Pharmacoepigenetics studies the underlying epigenetic marking patterns that lead to variation in an individual's response to medical treatment.[20]

### Clinical practice and drug discovery

[edit]
A toxicologist working in a lab

Pharmacology can be applied within clinical sciences. Clinical pharmacology is the application of pharmacological methods and principles in the study of drugs in humans.[21] An example of this is posology, which is the study of dosage of medicines.[22]

Pharmacology is closely related to toxicology. Both pharmacology and toxicology are scientific disciplines that focus on understanding the properties and actions of chemicals.[23] However, pharmacology emphasizes the therapeutic effects of chemicals, usually drugs or compounds that could become drugs, whereas toxicology is the study of chemical's adverse effects and risk assessment.[23]

Pharmacological knowledge is used to advise pharmacotherapy in medicine and pharmacy.

#### Drug discovery

[edit]

| This article may contain an excessive amount of intricate detail that may only interest a particular audience. Please help by spinning off or relocating any relevant information, and removing excessive detail that may be against Wikipedia's inclusion policy. (July 2019) (Learn how and when to remove this message)

Drug discovery is the field of study concerned with creating new drugs. It encompasses the subfields of drug design and development.[citation needed] Drug discovery starts with drug design, which is the inventive process of finding new drugs.[24] In the most basic sense, this involves the design of molecules that are complementary in shape and charge to a given biomolecular target.[25] After a lead compound has been identified through drug discovery, drug development involves bringing the drug to the market.[citation needed] Drug discovery is related to pharmacoeconomics, which is the sub-discipline of health economics that considers the value of drugs.[26][27] Pharmacoeconomics evaluates the cost and benefits of drugs in order to guide optimal healthcare resource allocation.[28] The techniques used for the discovery, formulation, manufacturing, and quality control of drugs discovery is studied by pharmaceutical engineering, a branch of engineering.[29] Safety pharmacology specializes in detecting and investigating potential undesirable effects of drugs.[30]

The drug discovery cycle

Development of medication is a vital concern to medicine, but also has strong economical and political implications. To protect the consumer and prevent abuse, many governments regulate the manufacture, sale, and administration of medication. In the United States, the main body that regulates pharmaceuticals is the Food and Drug Administration; they enforce standards set by the United States Pharmacopoeia. In the European Union, the main body that regulates pharmaceuticals is the European Medicines Agency (EMA), and they enforce standards set by the European Pharmacopoeia.

The metabolic stability and the reactivity of a library of candidate drug compounds have to be assessed for drug metabolism and toxicological studies. Many methods have been proposed for quantitative predictions in drug metabolism; one example of a recent computational method is SPORCalc.[31] A slight alteration to the chemical structure of a medicinal compound could alter its medicinal properties, depending on how the alteration relates to the structure of the substrate or receptor site on which it acts: this is called the structural activity relationship (SAR). When a useful activity has been identified, chemists will make many similar compounds called analogues, to try to maximize the desired medicinal effect(s). This can take anywhere from a few years to a decade or more, and is very expensive.[32] One must also determine how safe the medicine is to consume, its stability in the human body and the best form for delivery to the desired organ system, such as tablet or aerosol. After extensive testing, which can take up to six years, the new medicine is ready for marketing and selling.[32]

Because of these long timescales, and because out of every 5000 potential new medicines typically only one will ever reach the open market, this is an expensive way of doing things, often costing over 1 billion dollars. To recoup this outlay pharmaceutical companies may do a number of things:[32]

- Carefully research the demand for their potential new product before spending an outlay of company funds.[32]
- Obtain a patent on the new medicine preventing other companies from producing that medicine for a certain allocation of time.[32]

The inverse benefit law describes the relationship between a drugs therapeutic benefits and its marketing.

When designing drugs, the placebo effect must be considered to assess the drug's true therapeutic value.

Drug development uses techniques from medicinal chemistry to chemically design drugs. This overlaps with the biological approach of finding targets and physiological effects.

### Wider contexts

[edit]

Pharmacology can be studied in relation to wider contexts than the physiology of individuals. For example, pharmacoepidemiology concerns the variations of the effects of drugs in or between populations, it is the bridge between clinical pharmacology and epidemiology.[33][34] Pharmacoenvironmentology or environmental pharmacology is the study of the effects of used pharmaceuticals and personal care products (PPCPs) on the environment after their elimination from the body.[35] Human health and ecology are intimately related so environmental pharmacology studies the environmental effect of drugs and pharmaceuticals and personal care products in the environment.[36]

Drugs may also have ethnocultural importance, so ethnopharmacology studies the ethnic and cultural aspects of pharmacology.[37]

### Emerging fields

[edit]

Photopharmacology is an emerging approach in medicine in which drugs are activated and deactivated with light. The energy of light is used to change for shape and chemical properties of the drug, resulting in different biological activity.[38] This is done to ultimately achieve control when and where drugs are active in a reversible manner, to prevent side effects and pollution of drugs into the environment.[39][40]

Epigenetic therapy may offer an alternative 'master switch' to gene therapy to introduce persistent changes to the phenotype. Aging is well-known to be measurable through epigenetic clock.[41]

Drugs mays induce persistent changes. When they cause drugs to lose efficacy, it is called drug tolerance. On the other hand, they may introduce benign changes to the body. Psychoplastogen produce profound effects by regulating neuroplasticity. Psychostimulants prevent grey matter loss in ADHD patients, at therapeutic doses.[42]

## Theory of pharmacology

[edit]

| This section needs expansion. You can help by adding to it. (July 2019)

Pharmacology is the scientific study of drugs and their interactions with living systems. it is broadly divided into two main branches: Pharmacokinetics and Pharmacodynamics.

### Pharmacokinetics (PK)

[edit]

Pharmacokinetics refers to the movement of drugs within the body and describes what the body does to a drug. It includes four main processes:

- Absorption – How the drug enters the bloodstream.
- Distribution – How the drug spreads throughout the body's tissue and fluids.
- Metabolism – How the drug is chemically altered, primarily in the liver.
- Excretion – How the drug and its metabolites are eliminated, mainly through the kidneys.

Key parameters in pharmacokinetics include:

- Half-life (t1/2): The time required for the drug's plasma concentration to reduce by half.
- Volume of distribution (Vd): A theoretical volume that related the amount of drug in the body to the concentration in the blood.
- Clearance (Cl): The rate at which a drug is removed from the body.

### Pharmacodynamics (PD)

[edit]

Pharmacodynamics refers to the biochemical and physiological effects of drugs on the body and the mechanism of the action. it answers the question, "What does the drug do to the body?"

This include :

- Receptor binding – Most drugs exert their effects by binding to specific cell receptors (proteins on cell surfaces or inside cells)
- Dose-response relationship – Illustrated using drug-response curves, these relationships show the effect of different drug doses on the magnitude of a response.
- Therapeutic window – The range of doses between the minimum effective concentration and the minimum toxic concentration.

A trio of dose response curves. Dose response curves are studied extensively in pharmacology.

### Systems, receptors and ligands

[edit]

| This section needs expansion. You can help by adding to it. (July 2019)

The cholinergic synapse. Targets in synapses can be modulated with pharmacological agents. In this case, cholinergics (such as muscarine) and anticholinergics (such as atropine) target receptors; transporter inhibitors (such as hemicholinium) target membrane transport proteins and anticholinesterases (such as sarin) target enzymes.

Pharmacology is typically studied with respect to particular systems, for example endogenous neurotransmitter systems. The major systems studied in pharmacology can be categorized by their ligands and include acetylcholine, adrenaline, glutamate, GABA, dopamine, histamine, serotonin, cannabinoid, and opioid.

Molecular targets in pharmacology include receptors, enzymes, and membrane transport proteins. Enzymes can be targeted with enzyme inhibitors. Receptors are typically categorized based on structure and function. Major receptor types studied in pharmacology include G protein coupled receptors, ligand gated ion channels, and receptor tyrosine kinases.

Network pharmacology is a subfield of pharmacology that combines principles from pharmacology, systems biology, and network analysis to study the complex interactions between drugs and targets (e.g., receptors or enzymes etc.) in biological systems. The topology of a biochemical reaction network determines the shape of drug dose-response curve[43] as well as the type of drug-drug interactions,[44] thus can help designing efficient and safe therapeutic strategies. The topology Network pharmacology utilizes computational tools and network analysis algorithms to identify drug targets, predict drug-drug interactions, elucidate signaling pathways, and explore the polypharmacology of drugs.

### Pharmacodynamics

[edit]

| This section needs additional citations for verification. Please help improve this article by adding citations to reliable sources in this section. Unsourced material may be challenged and removed. (November 2023) (Learn how and when to remove this message)

Pharmacodynamics is defined as how the body reacts to the drugs. Pharmacodynamics theory often investigates the binding affinity of ligands to their receptors. Ligands can be agonists, partial agonists or antagonists at specific receptors in the body. Agonists bind to receptors and produce a biological response, a partial agonist produces a biological response lower than that of a full agonist, antagonists have affinity for a receptor but do not produce a biological response.

The ability of a ligand to produce a biological response is termed efficacy, in a dose-response profile it is indicated as percentage on the y-axis, where 100% is the maximal efficacy (all receptors are occupied).

Binding affinity is the ability of a ligand to form a ligand-receptor complex either through weak attractive forces (reversible) or covalent bond (irreversible), therefore efficacy is dependent on binding affinity.

Potency of drug is the measure of its effectiveness, EC50 is the drug concentration of a drug that produces an efficacy of 50% and the lower the concentration the higher the potency of the drug therefore EC50 can be used to compare potencies of drugs.

Medication is said to have a narrow or wide therapeutic index, certain safety factor, or therapeutic window. This describes the ratio of desired effect to toxic effect. A compound with a narrow therapeutic index (close to one) exerts its desired effect at a dose close to its toxic dose. A compound with a wide therapeutic index (greater than five) exerts its desired effect at a dose substantially below its toxic dose. Those with a narrow margin are more difficult to dose and administer, and may require therapeutic drug monitoring (examples are warfarin, some antiepileptics, aminoglycoside antibiotics). Most anti-cancer drugs have a narrow therapeutic margin: toxic side-effects are almost always encountered at doses used to kill tumors.

The effect of drugs can be described with Loewe additivity which is one of several common reference models.[44]

Other models include the Hill equation, Cheng-Prusoff equation and Schild regression.

### Pharmacokinetics

[edit]

| This section has multiple issues. Please help improve it or discuss these issues on the talk page. (Learn how and when to remove these messages)
| This section needs expansion. You can help by adding to it. (July 2019)
| This section may require cleanup to meet Wikipedia's quality standards. The specific problem is: Content needs to be generalised to encompass pharmacokinetics as a whole, not just individual ideas. Please help improve this section if you can. (July 2019) (Learn how and when to remove this message)
(Learn how and when to remove this message)

Pharmacokinetics is the study of the bodily absorption, distribution, metabolism, and excretion of drugs.[45]

When describing the pharmacokinetic properties of the chemical that is the active ingredient or active pharmaceutical ingredient (API), pharmacologists are often interested in L-ADME:

- Liberation – How is the API disintegrated (for solid oral forms (breaking down into smaller particles), dispersed, or dissolved from the medication?
- Absorption – How is the API absorbed (through the skin, the intestine, the oral mucosa)?
- Distribution – How does the API spread through the organism?
- Metabolism – Is the API converted chemically inside the body, and into which substances. Are these active (as well)? Could they be toxic?
- Excretion – How is the API excreted (through the bile, urine, breath, skin)?

Drug metabolism is assessed in pharmacokinetics and is important in drug research and prescribing.

Pharmacokinetics is the movement of the drug in the body, it is usually described as 'what the body does to the drug' the physico-chemical properties of a drug will affect the rate and extent of absorption, extent of distribution, metabolism and elimination. The drug needs to have the appropriate molecular weight, polarity etc. in order to be absorbed, the fraction of a drug that reaches the systemic circulation is termed bioavailability, this is simply a ratio of the peak plasma drug levels after oral administration and the drug concentration after an IV administration (first pass effect is avoided and therefore no amount drug is lost). A drug must be lipophilic (lipid soluble) in order to pass through biological membranes because biological membranes are made up of a lipid bilayer (phospholipids etc.). Once the drug reaches the blood circulation it is then distributed throughout the body and being more concentrated in highly perfused organs.

### Gene expression modulation and epigenetics

[edit]

Apart from classical pharmacological targets, drugs may exert effects through direct or indirect gene expression modulation, or even introduce persistent state changes through epigenetic reprogramming.

Therefore, drugs should be screened for off-target activity by gene expression profiling, in addition to conventional ligand binding, enzyme assays, etc.

## Administration, drug policy and safety

[edit]

### Drug policy

[edit]

In the United States, the Food and Drug Administration (FDA) is responsible for creating guidelines for the approval and use of drugs. The FDA requires that all approved drugs fulfill two requirements:

1. The drug must be found to be effective against the disease for which it is seeking approval (where 'effective' means only that the drug performed better than placebo or competitors in at least two trials).
2. The drug must meet safety criteria by being subject to animal and controlled human testing.

Gaining FDA approval usually takes several years. Testing done on animals must be extensive and must include several species to help in the evaluation of both the effectiveness and toxicity of the drug. The dosage of any drug approved for use is intended to fall within a range in which the drug produces a therapeutic effect or desired outcome.[46]

The safety and effectiveness of prescription drugs in the U.S. are regulated by the federal Prescription Drug Marketing Act of 1987.

The Medicines and Healthcare products Regulatory Agency (MHRA) has a similar role in the UK.

Medicare Part D is a prescription drug plan in the U.S.

The Prescription Drug Marketing Act (PDMA) is an act related to drug policy.

Prescription drugs are drugs regulated by legislation.

## Societies and education

[edit]

| This section does not cite any sources. Please help improve this section by adding citations to reliable sources. Unsourced material may be challenged and removed. (February 2016) (Learn how and when to remove this message)

### Societies and administration

[edit]

The International Union of Basic and Clinical Pharmacology, Federation of European Pharmacological Societies, and European Association for Clinical Pharmacology and Therapeutics are organizations representing standardization and regulation of clinical and scientific pharmacology.

Systems for medical classification of drugs with pharmaceutical codes have been developed. These include the National Drug Code (NDC), administered by Food and Drug Administration;[47] Drug Identification Number (DIN), administered by Health Canada under the Food and Drugs Act; Hong Kong Drug Registration, administered by the Pharmaceutical Service of the Department of Health (Hong Kong), and National Pharmaceutical Product Index in South Africa. Hierarchical systems have also been developed, including the Anatomical Therapeutic Chemical Classification System (AT, or ATC/DDD), administered by World Health Organization; Generic Product Identifier (GPI), a hierarchical classification number published by MediSpan and SNOMED, C axis. Ingredients of drugs have been categorized by Unique Ingredient Identifiers.

### Education

[edit]

The study of pharmacology overlaps with biomedical sciences and is the study of the effects of drugs on living organisms. Pharmacological research can lead to new drug discoveries, and promote a better understanding of human physiology. Students of pharmacology must have a detailed working knowledge of aspects in physiology, pathology, and chemistry. They may also require knowledge of plants as sources of pharmacologically active compounds.[37] Modern pharmacology is interdisciplinary and involves biophysical and computational sciences and analytical chemistry. A pharmacist needs to be well-equipped with knowledge on pharmacology for application in pharmaceutical research or pharmacy practice in hospitals or commercial organizations selling to customers. Pharmacologists, however, usually work in a laboratory undertaking research or development of new products. Pharmacological research is important in academic research (medical and non-medical), private industrial positions, science writing, scientific patents and law, consultation, biotech and pharmaceutical employment, the alcohol industry, food industry, forensics/law enforcement, public health, and environmental/ecological sciences. Pharmacology is often taught to pharmacy and medicine students as part of a Medical School curriculum.

## See also

[edit]

- Cosmeceuticals
- List of abbreviations used in medical prescriptions
- List of pharmaceutical companies
- List of withdrawn drugs
- Pharmaceutical company
- Pharmaceutical formulation
- Pharmaceutical physician

## References

[edit]

1. ^
   Vallance P, Smart TG (January 2006). "The future of pharmacology". British Journal of Pharmacology. 147 Suppl 1 (S1): S304–7. doi:10.1038/sj.bjp.0706454. PMC 1760753. PMID 16402118.
2. ^ "Definition of PHARMACOLOGY". Merriam-Webster. Retrieved 28 February 2023.
3. ^ "Pharmacy (n.)". Online Etymology Dictionary. Archived from the original on 2 October 2017. Retrieved 18 May 2017.
4. ^ "Pharmacology". Online Etymology Dictionary. Archived from the original on 2 October 2017. Retrieved 18 May 2017.
5. ^ Takács-Novák, K.; Avdeef, A. (August 1996). "Interlaboratory study of log P determination by shake-flask and potentiometric methods". Journal of Pharmaceutical and Biomedical Analysis. 14 (11): 1405–13. doi:10.1016/0731-7085(96)01773-6. PMID 8877846.
6. ^ Kritikos PG, Papadaki SP (1 January 1967). "The early history of the poppy and opium". Journal of the Archaeological Society of Athens.
7. ^ Luch, Andreas, ed. (2009). Molecular, Clinical and Environmental Toxicology. Experientia Supplementum. Vol. 99. Basel: Birkhäuser Basel. p. 20. doi:10.1007/978-3-7643-8336-7. ISBN 978-3-7643-8335-0.
8. ^ Sertürner F (1805). "Untitled letter to the editor". Journal der Pharmacie für Aerzte, Apotheker und Chemisten (Journal of Pharmacy for Physicians, Apothecaries, and Chemists). 13: 229–243.; see especially "III. Säure im Opium" (acid in opium), pp. 234–235, and "I. Nachtrag zur Charakteristik der Säure im Opium" (Addendum on the characteristics of the acid in opium), pp. 236–241.
9. ^ Brater DC, Daly WJ (May 2000). "Clinical pharmacology in the Middle Ages: principles that presage the 21st century". Clinical Pharmacology and Therapeutics. 67 (5): 447–50. doi:10.1067/mcp.2000.106465. PMID 10824622.
10. ^ Hollinger MA (2003). Introduction to pharmacology. CRC Press. p. 4. ISBN 0-415-28033-8.
11. ^ a b Rang HP (January 2006). "The receptor concept: pharmacology's big idea". British Journal of Pharmacology. 147 Suppl 1 (S1): S9-16. doi:10.1038/sj.bjp.0706457. PMC 1760743. PMID 16402126.
12. ^ Maehle AH, Prüll CR, Halliwell RF (August 2002). "The emergence of the drug receptor theory". Nature Reviews. Drug Discovery. 1 (8): 637–41. doi:10.1038/nrd875. PMID 12402503.
13. ^ Rang HP, Dale MM, Ritter JM, Flower RJ (2007). Pharmacology. China: Elsevier. ISBN 978-0-443-06911-6.
14. ^ Masood N. Khan; John W. Findlay, eds. (2009). Ligand-binding assays development, validation, and implementation in the drug development arena. Hoboken, N.J.: John Wiley & Sons. ISBN 978-0-470-54149-4.
15. ^ "Psychopharmacology". Psychology Today.
16. ^ "What is Psychopharmacology". American Society of Clinical Psychopharmacology. 29 November 2012.
17. ^ a b Kaddurah-Daouk R, Kristal BS, Weinshilboum RM (2008). "Metabolomics: a global biochemical approach to drug response and disease". Annual Review of Pharmacology and Toxicology. 48: 653–83. doi:10.1146/annurev.pharmtox.48.113006.094715. PMID 18184107.
18. ^ a b Kaddurah-Daouk R, Weinshilboum RM (February 2014). "Pharmacometabolomics: implications for clinical pharmacology and systems pharmacology". Clinical Pharmacology and Therapeutics. 95 (2): 154–67. doi:10.1038/clpt.2013.217. PMID 24193171.
19. ^ Rizkallah MR, Saad R, Aziz RK (September 2010). "The Human Microbiome Project, personalized medicine and the birth of pharmacomicrobiomics". Current Pharmacogenomics and Personalized Medicine. 8 (3): 182–93. doi:10.2174/187569210792246326.
20. ^ Gomez A, Ingelman-Sundberg M (April 2009). "Pharmacoepigenetics: its role in interindividual differences in drug response". Clinical Pharmacology and Therapeutics. 85 (4): 426–30. doi:10.1038/clpt.2009.2. PMID 19242404.
21. ^ "What is Clinical Pharmacology?". ascpt.org. Archived from the original on 31 October 2021. Retrieved 31 October 2021.
22. ^ "Posology, Factors Influencing Dose, Calculation of Doses". pharmamad.com. 23 January 2019. Archived from the original on 31 October 2021. Retrieved 31 October 2021.
23. ^ a b "The Science of Pharmacology & Toxicology". Faculty of Medicine, University of Toronto. Archived from the original on 16 July 2019. Retrieved 16 July 2019.
24. ^ Smith, H. John; Williams, H. John (2002). Liljefors, Tommy; Krogsgaard-Larsen, Povl; Madsen, Ulf (eds.). Textbook of Drug Design and Discovery. doi:10.1201/b12381. ISBN 978-0-429-21928-3.[page needed]
25. ^ "Introduction to Drug Design" (PDF). Archived (PDF) from the original on 31 October 2021. Retrieved 31 October 2021.[self-published source?]
26. ^ Mueller C, Schur C, O'Connell J (October 1997). "Prescription drug spending: the impact of age and chronic disease status". American Journal of Public Health. 87 (10): 1626–9. doi:10.2105/ajph.87.10.1626. PMC 1381124. PMID 9357343.
27. ^ Arnold RJ, Ekins S (2010). "Time for cooperation in health economics among the modelling community". PharmacoEconomics. 28 (8): 609–13. doi:10.2165/11537580-000000000-00000. PMID 20513161.
28. ^ Rai, Mahendra; Goyal, Richa (2018). "Pharmacoeconomics in Healthcare". Pharmaceutical Medicine and Translational Clinical Research. pp. 465–472. doi:10.1016/B978-0-12-802103-3.00034-1. ISBN 978-0-12-802103-3.
29. ^ Reklaitis GV, Khinast J, Muzzio F (November 2010). "Pharmaceutical engineering science—New approaches to pharmaceutical development and manufacturing". Chemical Engineering Science. 65 (21): iv–vii. Bibcode:2010ChEnS..65D...4R. doi:10.1016/j.ces.2010.08.041.
30. ^ Hite, Mark (25 June 2016). "Safety Pharmacology Approaches". International Journal of Toxicology. 16: 23–32. doi:10.1080/109158197227332.
31. ^ Smith J, Stein V (April 2009). "SPORCalc: A development of a database analysis that provides putative metabolic enzyme reactions for ligand-based drug design". Computational Biology and Chemistry. 33 (2): 149–59. doi:10.1016/j.compbiolchem.2008.11.002. PMID 19157988.
32. ^ a b c d e Newton D, Thorpe A, Otter C (2004). "What's in a Medicine (WM)". Revise A2 Chemistry. Heinemann Educational Publishers. p. 1. ISBN 0-435-58347-6.
33. ^ Ritter, James; Flower, Rod J.; Henderson, G.; MacEwan, David J.; Loke, Yoon Kong; Rang, H. P. (2020). Rang and Dale's pharmacology (Ninth ed.). Edinburgh: Elsevier. ISBN 978-0-7020-8060-9. OCLC 1081403059.[page needed]
34. ^ Strom, Brian L. (2021). "Study Designs Available for Pharmacoepidemiologic Studies". Textbook of Pharmacoepidemiology. pp. 20–34. doi:10.1002/9781119701101.ch2. ISBN 978-1-119-70107-1.
35. ^ Rahman SZ, Khan RA, Gupta V, Uddin M (July 2007). "Pharmacoenvironmentology--a component of pharmacovigilance". Environmental Health. 6 (1) 20. Bibcode:2007EnvHe...6...20R. doi:10.1186/1476-069X-6-20. PMC 1947975. PMID 17650313.
36. ^ Jena, Monalisa; Mishra, Archana; Maiti, Rituparna (26 March 2019). "Environmental pharmacology: source, impact and solution". Reviews on Environmental Health. 34 (1): 69–79. Bibcode:2019RvEH...34...69J. doi:10.1515/reveh-2018-0049. PMID 30854834.
37. ^ a b "International Society for Ethnopharmacology". International Society for Ethnopharmacology. Archived from the original on 21 January 2021. Retrieved 4 February 2021.
38. ^ Ricart-Ortega, Maria; Font, Joan; Llebaria, Amadeu (May 2019). "GPCR photopharmacology". Molecular and Cellular Endocrinology. 488: 36–51. doi:10.1016/j.mce.2019.03.003. hdl:10261/201805. PMID 30862498.
39. ^ Velema, Willem A.; Szymanski, Wiktor; Feringa, Ben L. (12 February 2014). "Photopharmacology: Beyond Proof of Principle" (PDF). Journal of the American Chemical Society. 136 (6): 2178–2191. Bibcode:2014JAChS.136.2178V. doi:10.1021/ja413063e. PMID 24456115.
40. ^ Broichhagen J, Frank JA, Trauner D (July 2015). "A roadmap to success in photopharmacology". Accounts of Chemical Research. 48 (7): 1947–60. doi:10.1021/acs.accounts.5b00129. PMID 26103428.
41. ^ Dai, Wanlin; Qiao, Xinbo; Fang, Yuanyuan; Guo, Renhao; Bai, Peng; Liu, Shuang; Li, Tingting; Jiang, Yutao; Wei, Shuang; Na, Zhijing; Xiao, Xue; Li, Da (26 November 2024). "Epigenetics-targeted drugs: current paradigms and future challenges". Signal Transduction and Targeted Therapy. 9 (1) 332: 1–71. doi:10.1038/s41392-024-02039-0. ISSN 2059-3635. PMC 11627502. PMID 39592582.
42. ^ Pretus, Clara; Ramos-Quiroga, J. Antoni; Richarte, Vanessa; Corrales, Montse; Picado, Marisol; Carmona, Susanna; Vilarroya, Óscar (1 December 2017). "Time and psychostimulants: Opposing long-term structural effects in the adult ADHD brain. A longitudinal MR study". European Neuropsychopharmacology. 27 (12): 1238–1247. doi:10.1016/j.euroneuro.2017.10.035. ISSN 0924-977X.
43. ^ van Wijk, Roeland; Tans, Sander J.; Wolde, Pieter Rein ten; Mashaghi, Alireza (18 June 2015). "Non-monotonic dynamics and crosstalk in signaling pathways and their implications for pharmacology". Scientific Reports. 5 (1) 11376. Bibcode:2015NatSR...511376V. doi:10.1038/srep11376. PMC 5155565. PMID 26087464.
44. ^ a b Babaei, Mehrad; Evers, Tom M.J.; Shokri, Fereshteh; Altucci, Lucia; de Lange, Elizabeth C.M.; Mashaghi, Alireza (March 2023). "Biochemical reaction network topology defines dose-dependent Drug–Drug interactions". Computers in Biology and Medicine. 155 106584. doi:10.1016/j.compbiomed.2023.106584. hdl:1887/3632248. PMID 36805215.
45. ^ "Pharmacokinetics". Merriam-Webster. Archived from the original on 16 July 2019. Retrieved 16 July 2019.
46. ^ Nagle H, Nagle B (2005). Pharmacology: An Introduction. Boston: McGraw Hill. ISBN 978-0-07-312275-5.[page needed]
47. ^ "National Drug Code Directory". U.S. Food and Drug Administration. 5 May 2017. Archived from the original on 27 May 2016. Retrieved 28 May 2019.

## External links

[edit]
Wikimedia Commons has media related to Pharmacology.

- American Society for Pharmacology and Experimental Therapeutics
- British Pharmacological Society
- International Conference on Harmonisation
- US Pharmacopeia
- International Union of Basic and Clinical Pharmacology
- IUPHAR Committee on Receptor Nomenclature and Drug Classification
- IUPHAR/BPS Guide to Pharmacology

## Further reading

[edit]

- Foreman, John C.; Johansen, Torben; Gibb, Alasdair J., eds. (2010). Textbook of Receptor Pharmacology. doi:10.1201/9781420052558. ISBN 978-0-429-14730-2.
- Brunton L (2011). Brunton LL, Chabner B, Knollmann BC (eds.). Goodman and Gilman's The Pharmacological Basis of Therapeutics (12 ed.). New York: McGraw-Hill. ISBN 978-0-07-162442-8.
- Whalen K (2014). Lippincott Illustrated Reviews: Pharmacology.

Retrieved from "https://en.wikipedia.org/w/index.php?title=Pharmacology&oldid=1317515875"
Categories:

- Pharmacology
- Biochemistry
- Life sciences industry

Hidden categories:

- CS1: long volume value
- Wikipedia articles needing page number citations from March 2025
- All articles with self-published sources
- Articles with self-published sources from March 2025
- Articles with short description
- Short description is different from Wikidata
- Articles needing cleanup from October 2025
- All pages needing cleanup
- Cleanup tagged articles with a reason field from October 2025
- Wikipedia pages needing cleanup from October 2025
- Use dmy dates from March 2014
- Articles containing Ancient Greek (to 1453)-language text
- All articles with unsourced statements
- Articles with unsourced statements from July 2019
- Wikipedia articles that are excessively detailed from July 2019
- All articles that are excessively detailed
- Wikipedia articles with style issues from July 2019
- All articles with style issues
- Articles with unsourced statements from March 2025
- Articles to be expanded from July 2019
- All articles to be expanded
- Articles needing additional references from November 2023
- All articles needing additional references
- Articles needing cleanup from July 2019
- Cleanup tagged articles with a reason field from July 2019
- Wikipedia pages needing cleanup from July 2019
- Articles with multiple maintenance issues
- Articles needing additional references from February 2016
- Commons category link from Wikidata
- Articles with excerpts

Pharmacology
Add topic